@@ -3,7 +3,7 @@
 
 """
     GNOME Shell integration for Chrome
-    Copyright (C) 2016  Yuri Konotopov <ykonotopov@gnome.org>
+    Copyright (C) 2016-2018  Yuri Konotopov <ykonotopov@gnome.org>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,13 @@ import struct
 import sys
 import traceback
 
-CONNECTOR_VERSION = 8.2
+REQUESTS_IMPORTED = True
+try:
+    import requests
+except ImportError:
+    REQUESTS_IMPORTED = False
+
+CONNECTOR_VERSION = 10
 DEBUG_ENABLED = False
 
 SHELL_SCHEMA = "org.gnome.shell"
@@ -135,12 +141,6 @@ class ChromeGNOMEShell(Gio.Application):
         action.connect('activate', callback)
         self.add_action(action)
 
-    def do_local_command_line(self, arguments):
-        if '--gapplication-service' in arguments:
-            arguments.remove('--gapplication-service')
-
-        return Gio.Application.do_local_command_line(self, arguments)
-
     # Service events
     # noinspection PyUnusedLocal
     def on_create_notification(self, source, request):
@@ -360,27 +360,39 @@ class ChromeGNOMEShell(Gio.Application):
         debug('Execute: to %s' % request['execute'])
 
         if request['execute'] == 'initialize':
-            settings = Gio.Settings.new(SHELL_SCHEMA)
+            source = Gio.SettingsSchemaSource.get_default()
             shell_version = self.shell_proxy.get_cached_property("ShellVersion")
-            if EXTENSION_DISABLE_VERSION_CHECK_KEY in settings.keys():
-                disable_version_check = settings.get_boolean(EXTENSION_DISABLE_VERSION_CHECK_KEY)
-            else:
-                disable_version_check = False
 
-            self.send_message(
-                {
-                    'success': True,
-                    'properties': {
-                        'connectorVersion': CONNECTOR_VERSION,
-                        'shellVersion': shell_version.unpack() if shell_version is not None else None,
-                        'versionValidationEnabled': not disable_version_check,
-                        'supports': [
-                            'notifications',
-                            'update-check'
-                        ]
+            if source is not None and source.lookup(SHELL_SCHEMA, True) is not None and shell_version is not None:
+                settings = Gio.Settings.new(SHELL_SCHEMA)
+
+                if EXTENSION_DISABLE_VERSION_CHECK_KEY in settings.keys():
+                    disable_version_check = settings.get_boolean(EXTENSION_DISABLE_VERSION_CHECK_KEY)
+                else:
+                    disable_version_check = False
+
+                supports = ['notifications', "update-enabled"]
+                if REQUESTS_IMPORTED:
+                    supports.append('update-check')
+
+                self.send_message(
+                    {
+                        'success': True,
+                        'properties': {
+                            'connectorVersion': CONNECTOR_VERSION,
+                            'shellVersion': shell_version.unpack() if shell_version is not None else None,
+                            'versionValidationEnabled': not disable_version_check,
+                            'supports': supports
+                        }
                     }
-                }
-            )
+                )
+            else:
+                self.send_message(
+                    {
+                        'success': False,
+                        'message': "no_gnome_shell"
+                    }
+                )
 
         elif request['execute'] == 'subscribeSignals':
             if not self.shellAppearedId:
@@ -464,10 +476,14 @@ class ChromeGNOMEShell(Gio.Application):
 
         elif request['execute'] == 'checkUpdate':
             update_url = 'https://extensions.gnome.org/update-info/'
+            enabled_only = True
             if 'url' in request:
                 update_url = request['url']
 
-            self.check_update(update_url)
+            if 'enabledOnly' in request:
+                enabled_only = request['enabledOnly']
+
+            self.check_update(update_url, enabled_only)
 
         elif request['execute'] == 'createNotification':
             Gio.DBusActionGroup.get(
@@ -486,7 +502,7 @@ class ChromeGNOMEShell(Gio.Application):
 
         debug('Execute: from %s' % request['execute'])
 
-    def check_update(self, update_url):
+    def check_update(self, update_url, enabled_only):
         result = self.shell_proxy.call_sync(
             "ListExtensions",
             None,
@@ -496,6 +512,8 @@ class ChromeGNOMEShell(Gio.Application):
         )
 
         extensions = result.unpack()[0]
+        settings = Gio.Settings.new(SHELL_SCHEMA)
+        enabled_extensions = settings.get_strv(ENABLED_EXTENSIONS_KEY)
 
         if extensions:
             http_request = {
@@ -506,7 +524,7 @@ class ChromeGNOMEShell(Gio.Application):
             for uuid in extensions:
                 # gnome-shell/js/misc/extensionUtils.js
                 # EXTENSION_TYPE.PER_USER = 2
-                if is_uuid(uuid) and extensions[uuid]['type'] == 2:
+                if is_uuid(uuid) and extensions[uuid]['type'] == 2 and (not enabled_only or uuid in enabled_extensions):
                     try:
                         http_request['installed'][uuid] = {
                             'version': int(extensions[uuid]['version'])
@@ -518,10 +536,21 @@ class ChromeGNOMEShell(Gio.Application):
 
             http_request['installed'] = json.dumps(http_request['installed'])
 
+            proxies = Gio.ProxyResolver.get_default().lookup(update_url)
+            if proxies is not None:
+                proxy = proxies[0]
+                if proxy.startswith('direct'):
+                    proxies = None
+                else:
+                    proxies = {}
+                    for scheme in ('http', 'https'):
+                        proxies[scheme] = proxy
+
             try:
                 response = requests.get(
                     update_url,
                     params=http_request,
+                    proxies=proxies,
                     timeout=5
                 )
                 response.raise_for_status()
@@ -546,9 +575,14 @@ class ChromeGNOMEShell(Gio.Application):
 
 
 if __name__ == '__main__':
-    debug('Main. Use CTRL+D to quit.')
-    app = ChromeGNOMEShell('--gapplication-service' in sys.argv)
+    debug('Main. Use Ctrl+D to quit.')
 
+    run_as_service = False
+    if '--gapplication-service' in sys.argv:
+        run_as_service = True
+        sys.argv.remove('--gapplication-service')
+
+    app = ChromeGNOMEShell(run_as_service)
     app.run(sys.argv)
 
     debug('Quit')
