@@ -1,6 +1,6 @@
 /*
     GNOME Shell integration for Chrome
-    Copyright (C) 2016  Yuri Konotopov <ykonotopov@gnome.org>
+    Copyright (C) 2016-2018  Yuri Konotopov <ykonotopov@gnome.org>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -9,7 +9,7 @@
  */
 
 GS_CHROME_ID				= chrome.runtime.id;
-PLATFORMS_WHITELIST			= ["linux", "openbsd"];
+PLATFORMS_WHITELIST			= ["freebsd", "linux", "openbsd"];
 
 COMPAT = {
 	IS_FIREFOX:	 (typeof(InstallTrigger) !== 'undefined'),
@@ -18,11 +18,12 @@ COMPAT = {
 
 NOTIFICATION_SYNC_FAILED		= 'gs-chrome-sync-fail';
 NOTIFICATION_UPDATE_AVAILABLE		= 'gs-chrome-update';
-NOTIFICATION_UPDATE_CHECK_FAILED	= 'gs-chrome-update-fail';
 ALARM_UPDATE_CHECK			= 'gs-chrome-update-check';
 
 MESSAGE_NEXT_UPDATE_CHANGED		= 'gs-next-update-changed';
 MESSAGE_SYNC_FROM_REMOTE		= 'gs-sync-from-remote';
+MESSAGE_IDLE_PERMISSION_ADDED	= 'gs-idle-added';
+MESSAGE_IDLE_PERMISSION_REMOVED	= 'gs-idle-removed';
 
 SIGNAL_EXTENSION_CHANGED		= 'ExtensionStatusChanged';
 SIGNAL_NOTIFICATION_ACTION		= 'NotificationAction';
@@ -41,16 +42,18 @@ UPDATE_URL				= EXTENSIONS_WEBSITE + 'update-info/';
 DEFAULT_SYNC_OPTIONS			= {
 	showReleaseNotes:	true,
 	updateCheck:		true,
+	updateCheckEnabledOnly: true,
 	updateCheckPeriod:	6
 };
 
 DEFAULT_LOCAL_OPTIONS			= {
-	syncExtensions:		false
+	syncExtensions:		false,
+	useLightIcon:		false
 };
 
 EXTERNAL_MESSAGES			= [
-	"connecting_host_app",
-	"error_extension_response",
+	"error_connector_response",
+	"no_gnome_shell",
 	"no_host_connector",
 	"warning_apis_missing"
 ];
