@@ -1,6 +1,6 @@
 /*
     GNOME Shell integration for Chrome
-    Copyright (C) 2016  Yuri Konotopov <ykonotopov@gnome.org>
+    Copyright (C) 2016-2018  Yuri Konotopov <ykonotopov@gnome.org>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,16 +13,20 @@ function save_options()
 	var showReleaseNotes = $('#show_release_notes_yes').prop('checked');
 	var syncExtensions = $('#synchronize_extensions_yes').prop('checked');
 	var updateCheck = $('#update_check_yes').prop('checked');
+	var updateCheckEnabledOnly = $('#update_check_enabled_yes').prop('checked');
 	var updateCheckPeriod = $('#update_check_period').val();
+	var useLightIcon = $('#use_light_icon_yes').prop('checked');
 	updateCheckPeriod = Math.max(3, updateCheckPeriod);
 
 	chrome.storage.sync.set({
 		showReleaseNotes:	showReleaseNotes,
 		updateCheck:		updateCheck,
+		updateCheckEnabledOnly: updateCheckEnabledOnly,
 		updateCheckPeriod:	updateCheckPeriod
 	}, function () {
 		chrome.storage.local.set({
-			syncExtensions:	syncExtensions
+			syncExtensions:	syncExtensions,
+			useLightIcon:	useLightIcon
 		}, function() {
 			if(syncExtensions)
 			{
@@ -49,7 +53,7 @@ function save_options()
 						});
 					}).fail(function (message) {
 						$('#error')
-							.text(message)
+							.html(message)
 							.show()
 							.delay(15000)
 							.hide(250);
@@ -83,25 +87,90 @@ function restore_options()
 	tabby.init();
 
 	chrome.storage.sync.get(DEFAULT_SYNC_OPTIONS, function (items) {
-		setCheckUpdate(items.updateCheck);
-		$('#update_check_period').val(items.updateCheckPeriod);
+		function toggle_notice(show, id) {
+			let notice = $('#' + id)
+				.closest('dl')
+				.find('dt br, dt span.notice');
+
+			if (show)
+			{
+				notice.show();
+			}
+			else
+			{
+				notice.hide();
+			}
+		}
+
+		function toggle_update_notice(show) {
+			toggle_notice(show, "update_check_yes");
+		}
+
+		function toggle_update_enable_notice(show) {
+			toggle_notice(show, "update_check_enabled_yes");
+		}
+
+		function disable_update_check() {
+			if (items.updateCheck)
+			{
+				items.updateCheck = false;
+
+				chrome.storage.sync.set({
+					updateCheck: items.updateCheck
+				});
+			}
+
+			toggle_update_notice(true);
+		}
+
+		function disable_update_enabled_only() {
+			if (items.updateCheckEnabledOnly)
+			{
+				items.updateCheckEnabledOnly = false;
+
+				chrome.storage.sync.set({
+					updateCheckEnabledOnly: items.updateCheckEnabledOnly
+				});
+			}
+
+			toggle_update_enable_notice(true);
+		}
+
+		GSC.onInitialize().then(function (response) {
+			if (!GSC.nativeUpdateCheckSupported(response))
+			{
+				disable_update_check();
+			}
+			else
+			{
+				$("input[name='update_check'], #update_check_period").removeAttr('disabled');
+				$('#update_check_period').val(items.updateCheckPeriod);
+				toggle_update_notice(false);
+				retrieveUpdateTimes();
+			}
+
+			if (!GSC.nativeUpdateCheckEnabledOnlySupported(response))
+			{
+				disable_update_enabled_only();
+			}
+			else
+			{
+				$("input[name='update_check_enabled']").removeAttr('disabled');
+				toggle_update_enable_notice(false);
+			}
+
+			setCheckUpdate(items.updateCheck);
+			setCheckUpdateEnabledOnly(items.updateCheckEnabledOnly);
+		}, function(response) {
+			disable_update_check();
+		});
+
 		setReleaseNotes(items.showReleaseNotes);
-
-		retrieveUpdateTimes();
-	});
-
-	chrome.permissions.contains({
-		permissions: ["webRequest"]
-	}, function(result) {
-		setNetworkErrors(result);
 	});
 
 	if(COMPAT.SYNC_STORAGE)
 	{
 		updateSynchronizationStatus();
-		chrome.storage.local.get(DEFAULT_LOCAL_OPTIONS, function (items) {
-			setSyncExtensions(items.syncExtensions);
-		});
 	}
 	else
 	{
@@ -109,15 +178,22 @@ function restore_options()
 		$('#synchronize_extensions_yes').closest('dl').hide();
 	}
 
-	if(COMPAT.IS_FIREFOX)
-	{
-		$('dialog').hide();
-	}
+	chrome.storage.local.get(DEFAULT_LOCAL_OPTIONS, function (items) {
+		if(items.syncExtensions)
+		{
+			chrome.permissions.contains({
+				permissions: ["idle"]
+			}, function (result) {
+				setSyncExtensions(result);
+			});
+		}
+		else if(COMPAT.SYNC_STORAGE)
+		{
+			setSyncExtensions(false);
+		}
 
-	if(!COMPAT.PERMISSIONS_CONTAINS)
-	{
-		$('#show_network_errors_yes').parents('dl:first').hide();
-	}
+		setLightIcon(items.useLightIcon);
+	});
 }
 
 function retrieveUpdateTimes()
@@ -160,6 +236,22 @@ function setCheckUpdate(result)
 		$('#update_check_no').prop('checked', true);
 }
 
+function setCheckUpdateEnabledOnly(result)
+{
+	if(result)
+		$('#update_check_enabled_yes').prop('checked', true);
+	else
+		$('#update_check_enabled_no').prop('checked', true);
+}
+
+function setLightIcon(result)
+{
+	if(result)
+		$('#use_light_icon_yes').prop('checked', true);
+	else
+		$('#use_light_icon_no').prop('checked', true);
+}
+
 function setReleaseNotes(result)
 {
 	if(result)
@@ -168,14 +260,6 @@ function setReleaseNotes(result)
 		$('#show_release_notes_no').prop('checked', true);
 }
 
-function setNetworkErrors(result)
-{
-	if(result)
-		$('#show_network_errors_yes').prop('checked', true);
-	else
-		$('#show_network_errors_no').prop('checked', true);
-}
-
 function setSyncExtensions(result)
 {
 	if(result)
@@ -184,22 +268,51 @@ function setSyncExtensions(result)
 		$('#synchronize_extensions_no').prop('checked', true);
 }
 
-function handleWebrequestPermission()
+function handleSynchronize()
 {
-	if($('#show_network_errors_yes').prop('checked'))
+	if($('#synchronize_extensions_yes').is(':checked'))
 	{
 		chrome.permissions.request({
-			permissions: ["webRequest"]
+			permissions: ["idle"]
 		}, function(granted) {
-			setNetworkErrors(granted);
+			if(granted)
+			{
+				if(!COMPAT.PERMISSIONS_EVENTS)
+				{
+					chrome.runtime.sendMessage(GS_CHROME_ID, MESSAGE_IDLE_PERMISSION_ADDED);
+				}
+
+				chrome.storage.sync.get({
+					extensions: {}
+				}, function (options) {
+					if(!$.isEmptyObject(options.extensions))
+					{
+						document.getElementById('syncChoice').showModal();
+					}
+				});
+			}
+			else
+			{
+				if(!COMPAT.PERMISSIONS_EVENTS)
+				{
+					chrome.runtime.sendMessage(GS_CHROME_ID, MESSAGE_IDLE_PERMISSION_REMOVED);
+				}
+
+				setSyncExtensions(false);
+			}
 		});
 	}
 	else
 	{
 		chrome.permissions.remove({
-			permissions: ["webRequest"]
+			permissions: ["idle"]
 		}, function(removed) {
-			setNetworkErrors(!removed);
+			if(removed && !COMPAT.PERMISSIONS_EVENTS)
+			{
+				chrome.runtime.sendMessage(GS_CHROME_ID, MESSAGE_IDLE_PERMISSION_REMOVED);
+			}
+
+			setSyncExtensions(!removed);
 		});
 	}
 }
@@ -252,7 +365,7 @@ function updateSynchronizationStatus()
 		});
 	}).fail(function (message) {
 		$('#error')
-			.text(message)
+			.html(message)
 			.show()
 			.delay(15000)
 			.hide(250);
@@ -263,26 +376,26 @@ i18n();
 
 document.addEventListener('DOMContentLoaded', restore_options);
 document.getElementById('save').addEventListener('click', save_options);
-$.each(document.getElementsByName('show_network_errors'), function(index, control) {
-	control.addEventListener('change', handleWebrequestPermission);
+
+$.each(document.getElementsByName('synchronize_extensions'), function(index, control) {
+	control.addEventListener('change', handleSynchronize);
 });
 
+
+// Compat: Firefox
+dialogPolyfill.registerDialog(document.getElementById('syncChoice'));
 document.getElementById('syncChoice').addEventListener('close', function() {
 	if(document.getElementById('syncChoice').returnValue === 'cancel')
 	{
-		$('#synchronize_extensions_no').prop('checked', 'checked');
-	}
-});
-$('input[type="radio"][name="synchronize_extensions"]').change(function() {
-	if($('#synchronize_extensions_yes').is(':checked'))
-	{
-		chrome.storage.sync.get({
-			extensions: {}
-		}, function (options) {
-			if(!$.isEmptyObject(options.extensions))
+		chrome.permissions.remove({
+			permissions: ["idle"]
+		}, function(removed) {
+			if(removed && !COMPAT.PERMISSIONS_EVENTS)
 			{
-				document.getElementById('syncChoice').showModal();
+				chrome.runtime.sendMessage(GS_CHROME_ID, MESSAGE_IDLE_PERMISSION_REMOVED);
 			}
+
+			setSyncExtensions(!removed);
 		});
 	}
 });
